@@ -28,6 +28,9 @@ class User(Base):
     # Временный пароль
     temppass = Column('user_temppass', String(50))
 
+    # Права доступа пользователя
+    access = Column('user_access', Integer, default=0)
+
     def __repr__(self):
         return '<User {} (id={})>'.format(self, self.id)
     
@@ -79,6 +82,9 @@ class Student(Base):
     payment_form_id = Column('payment_forms_id', ForeignKey('univer_payment_forms.payment_form_id'))
     payment_form = relationship('PaymentForm')
 
+    country_id = Column(ForeignKey('univer_country.country_id'))
+    country = relationship('Country')
+
     # Пол
     sex = Column('students_sex', Integer)
 
